#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 casa-client
version:              0.0.1
visibility:           public
id:                   casa-client-0.0.1-JgFxKVuVsMP6ATMCdh0T9U
key:                  casa-client-0.0.1-JgFxKVuVsMP6ATMCdh0T9U
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Client for Casa
description:          Client for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  f42ee8f15b935ebc6424b0619159e780
exposed:              True
exposed-modules:      Casa.Client
hidden-modules:       Paths_casa_client
import-dirs:          /usr/lib/ghc-8.10.5/site-local/casa-client-0.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/casa-client-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/casa-client-0.0.1
hs-libraries:         HScasa-client-0.0.1-JgFxKVuVsMP6ATMCdh0T9U
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    base16-bytestring-1.0.1.0-HvKbW9RCiAQ5xlJPICEukR
    bytestring-0.10.12.0 casa-types-0.0.2-Hku0FdRj4LL76OxDsCbHPm
    conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE
    conduit-extra-1.3.5-6wbdzvOjyuAGkpGhMnpbur
    cryptonite-0.29-KSQcZnQaH5M3lIm9Vzc7YS exceptions-0.10.4
    http-conduit-2.3.8-EHVj4SxGcYE5sNggtZCndH
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    memory-0.16.0-E1gXzMJzgEcJ8QhI9dLs6S
    network-uri-2.6.4.1-4m8gp52oIfHLdE9VhQrWxs
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe template-haskell-2.16.0.0
    text-1.2.4.1 th-lift-0.8.2-A94jWiBJfaQF1v2Vq9YgsH
    unliftio-core-0.2.0.1-1ibY1oF6Hkc5ZYjZ4yW3Lp
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

